@@ -525,9 +525,14 @@ fn handle_merge<
                 // position, which is incorrect if the split key/value
                 // comes from the right-hand side of the current
                 // cursor position.
+                //
+                // This can happen in exactly two situations:
+                // - when the element we are deleting is the one we are
+                //   skipping here.
+                // - when we are deleting in the rightmost child of a
+                //   page.
                 if cursor.len() > 0 && !mod_is_left {
-                    let curs = cursor.current_mut();
-                    P::move_next(&mut curs.cursor);
+                    P::move_next(&mut last_op.c1);
                 }
                 // If the split key is the replacement element, we have
                 // already increased its counter when we deleted it from
